@@ -61,12 +61,22 @@
 
 DISCOVER_BACKEND_PLUGIN(FlatpakBackend)
 
+QDebug operator<<(QDebug debug, const FlatpakResource::Id& id)
+{
+    QDebugStateSaver saver(debug);
+    debug.nospace() << "FlatpakResource::Id(";
+    debug.nospace() << "name:" << id.id << ',';
+    debug.nospace() << "branch:" << id.branch << ',';
+    debug.nospace() << "origin:" << id.origin << ',';
+    debug.nospace() << "type:" << id.type;
+    debug.nospace() << ')';
+    return debug;
+}
+
 static FlatpakResource::Id idForInstalledRef(FlatpakInstallation *installation, FlatpakInstalledRef *ref)
 {
     const FlatpakResource::ResourceType appType = flatpak_ref_get_kind(FLATPAK_REF(ref)) == FLATPAK_REF_KIND_APP ? FlatpakResource::DesktopApp : FlatpakResource::Runtime;
-    const QString name = QLatin1String(flatpak_ref_get_name(FLATPAK_REF(ref)));
-    const QString appId = appType == FlatpakResource::DesktopApp ? QLatin1String(flatpak_ref_get_name(FLATPAK_REF(ref))) : name;
-
+    const QString appId = QLatin1String(flatpak_ref_get_name(FLATPAK_REF(ref)));
     const QString arch = QString::fromUtf8(flatpak_ref_get_arch(FLATPAK_REF(ref)));
     const QString branch = QString::fromUtf8(flatpak_ref_get_branch(FLATPAK_REF(ref)));
 
@@ -619,10 +629,10 @@ bool FlatpakBackend::loadAppsFromAppstreamData(FlatpakInstallation *flatpakInsta
 void FlatpakBackend::integrateRemote(FlatpakInstallation *flatpakInstallation, FlatpakRemote *remote)
 {
     Q_ASSERT(m_refreshAppstreamMetadataJobs != 0);
-    m_refreshAppstreamMetadataJobs--;
 
     FlatpakSource source(remote);
     if (!source.isEnabled() || flatpak_remote_get_noenumerate(remote)) {
+        m_refreshAppstreamMetadataJobs--;
         return;
     }
 
@@ -630,6 +640,7 @@ void FlatpakBackend::integrateRemote(FlatpakInstallation *flatpakInstallation, F
     const QString appstreamIconsPath = source.appstreamDir() + QLatin1String("/icons/");
     const QString appDirFileName = appstreamDirPath + QLatin1String("/appstream.xml.gz");
     if (!QFile::exists(appDirFileName)) {
+        m_refreshAppstreamMetadataJobs--;
         qWarning() << "No" << appDirFileName << "appstream metadata found for" << source.name();
         return;
     }
@@ -644,7 +655,9 @@ void FlatpakBackend::integrateRemote(FlatpakInstallation *flatpakInstallation, F
             resource->setOrigin(sourceName);
             addResource(resource);
         }
-        if (!m_refreshAppstreamMetadataJobs) {
+
+        m_refreshAppstreamMetadataJobs--;
+        if (m_refreshAppstreamMetadataJobs == 0) {
             loadInstalledApps();
             checkForUpdates();
 
@@ -792,7 +805,7 @@ void FlatpakBackend::onFetchUpdatesFinished(FlatpakInstallation *flatpakInstalla
             resource->setState(AbstractResource::Upgradeable);
             updateAppSize(flatpakInstallation, resource);
         } else
-            qWarning() << "could not find updated resource" << idForInstalledRef(flatpakInstallation, ref).id << m_resources.size();
+            qWarning() << "could not find updated resource" << flatpak_ref_get_name(FLATPAK_REF(ref)) << m_resources.size();
     }
 }
 
