@@ -55,14 +55,15 @@ public:
     enum ResourceType {
         DesktopApp = 0,
         Runtime,
+        Extension,
         Source
     };
 
     struct Id {
-        FlatpakInstallation * installation;
+        FlatpakInstallation * const installation;
         QString origin;
         FlatpakResource::ResourceType type;
-        QString id;
+        const QString id;
         QString branch;
         QString arch;
         bool operator!=(const Id& other) const { return !operator==(other); }
@@ -100,7 +101,7 @@ public:
     QVariant icon() const override;
     QString installedVersion() const override;
     int installedSize() const;
-    bool isTechnical() const override;
+    AbstractResource::Type type() const override;
     QUrl homepage() override;
     QUrl helpURL() override;
     QUrl bugURL() override;
@@ -119,11 +120,13 @@ public:
     int size() override;
     QString sizeDescription() override;
     AbstractResource::State state() override;
-    ResourceType type() const;
+    ResourceType resourceType() const;
     QString typeAsString() const;
     FlatpakResource::Id uniqueId() const;
     QUrl url() const override;
     QDate releaseDate() const override;
+    QString author() const override;
+    QStringList extends() const override;
 
     FlatpakInstallation* installation() const { return m_id.installation; }
 
@@ -148,7 +151,9 @@ public:
 //     void setAddonInstalled(const QString& addon, bool installed);
 
     void updateFromRef(FlatpakRef* ref);
+    QString ref() const;
     QString sourceIcon() const override;
+    QString installPath() const;
 
 Q_SIGNALS:
     void propertyStateChanged(PropertyKind kind, PropertyState state);
