@@ -195,7 +195,14 @@ void FwupdResource::setDeviceDetails(FwupdDevice* dev)
     m_description = QString::fromUtf8((fwupd_device_get_description(dev)));
 
     if (fwupd_device_get_icons(dev)->len >= 1)
-        m_iconName = QString::fromUtf8((const gchar *)g_ptr_array_index(fwupd_device_get_icons(dev), 0));// Check wether given icon exists or not!
+        m_iconName = QString::fromUtf8((const gchar *)g_ptr_array_index(fwupd_device_get_icons(dev), 0));// Check whether given icon exists or not!
     else
-        m_iconName = QString::fromUtf8("device-notifier");
+        m_iconName = QStringLiteral("device-notifier");
+}
+
+QString FwupdResource::cacheFile() const
+{
+    const auto filename_cache = FwupdBackend::cacheFile(QStringLiteral("fwupd"), QFileInfo(QUrl(m_updateURI).path()).fileName());
+    Q_ASSERT(!filename_cache.isEmpty());
+    return filename_cache;
 }
