@@ -33,13 +33,18 @@ class LocalFilePKResource : public PackageKitResource
         QString comment() override;
 
         AbstractResource::State state() override { return m_state; }
+        QString license() override;
         int size() override;
         void markInstalled();
         QString origin() const override;
+        void fetchDetails() override;
+        bool canExecute() const override { return !m_exec.isEmpty(); }
+        void invokeApplication() const override;
 
     private:
         AbstractResource::State m_state = AbstractResource::None;
         QUrl m_path;
+        QString m_exec;
 };
 
 #endif // LOCALFILEPKRESOURCE_H
