@@ -43,15 +43,17 @@ class PackageKitResource : public AbstractResource
         QString license() override;
         QString origin() const override;
         QString section() override;
-        bool isTechnical() const override;
+        AbstractResource::Type type() const override;
         int size() override;
         void fetchChangelog() override;
-        
+        void fetchUpdateDetails() override;
+
         QList<PackageState> addonsInformation() override;
         State state() override;
         
         QString installedVersion() const override;
         QString availableVersion() const override;
+        QString author() const override { return {}; }
         virtual QStringList allPackageNames() const;
         QString installedPackageId() const;
         QString availablePackageId() const;
@@ -96,19 +98,19 @@ class PackageKitResource : public AbstractResource
                           const QDateTime &issued,
                           const QDateTime &updated);
 
-    private Q_SLOTS:
         void failedFetchingDetails(PackageKit::Transaction::Error, const QString& msg);
 
+    protected:
+        PackageKit::Details m_details;
+
     private:
         void fetchDependencies();
-        void setDependencies(const QStringList &deps);
         /** fetches details individually, it's better if done in batch, like for updates */
-        void fetchDetails();
+        virtual void fetchDetails();
 
         QMap<PackageKit::Transaction::Info, QStringList> m_packages;
         const QString m_summary;
         const QString m_name;
-        PackageKit::Details m_details;
         int m_dependenciesCount = -1;
         static const QStringList m_objects;
 };
