@@ -53,11 +53,12 @@ public:
     QString comment() override;
     QString name() const override;
     QString packageName() const override;
-    bool isTechnical() const override;
+    AbstractResource::Type type() const override;
     bool canExecute() const override { return true; }
     void invokeApplication() const override;
     void fetchChangelog() override;
     void fetchScreenshots() override;
+    QString author() const override;
     QList<PackageState> addonsInformation() override { return {}; }
     void setSnap(const QSharedPointer<QSnapdSnap> &snap);
 
